// Copyright 2000-2019 JetBrains s.r.o. Use of this source code is governed by the Apache 2.0 license that can be found in the LICENSE file.
package com.jetbrains.completion.ranker

import com.completion.ranker.model.scala.MLWhiteBox
import com.intellij.ide.plugins.PluginManagerCore
import com.intellij.internal.ml.DecisionFunction
import com.intellij.internal.ml.ModelMetadata
import com.intellij.internal.ml.completion.CompletionRankingModelBase
import com.intellij.internal.ml.completion.JarCompletionModelProvider
import com.intellij.lang.Language
import com.intellij.openapi.extensions.PluginId

class FallbackScalaMLRankingProvider : JarCompletionModelProvider("Scala", "scala_features"), WeakModelProvider {
  override fun createModel(metadata: ModelMetadata): DecisionFunction {
    return object : CompletionRankingModelBase(metadata) {
      override fun predict(features: DoubleArray?): Double = MLWhiteBox.makePredict(features)
    }
  }

  override fun isLanguageSupported(language: Language): Boolean = language.id.compareTo("Scala", ignoreCase = true) == 0

  override fun canBeUsed(): Boolean {
    return PluginManagerCore.getPlugin(PluginId.findId(SCALA_PLUGIN_ID))?.isEnabled ?: false
  }

  override fun shouldReplace(): Boolean = false

  private companion object {
    private const val SCALA_PLUGIN_ID = "org.intellij.scala"
  }
}